@@ -36,15 +36,15 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'Routes'
-copyright = '2005-2015, Ben Bangert, Mike Orr'
+copyright = '2005-2016, Ben Bangert, Mike Orr, and numerous contributers'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '1.13'
+version = '2.3'
 # The full version, including alpha/beta/rc tags.
-release = '1.13'
+release = '2.3.1'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
